@@ -1,12 +1,37 @@
-mod link_rel;
+pub mod indieauth;
+pub mod link_rel;
+pub mod webmention;
 
 #[cfg(test)]
 mod test;
 
-static APP_USER_AGENT: &str = concat!(env!("CARGO_PKG_NAME"), "/", env!("CARGO_PKG_VERSION"),);
+#[derive(thiserror::Error, Debug)]
+pub enum Error {
+    #[error("No {rel:?} endpoints were found at {url:?}")]
+    NoEndpointsFound { rel: String, url: String },
+
+    #[error(
+        "The Webmention endpoint at {url:?} returned a unexpected status code of {status_code:?})"
+    )]
+    WebmentionUnsupportedStatusCode {
+        status_code: reqwest::StatusCode,
+        url: String,
+    },
+
+    #[error(transparent)]
+    Other(#[from] anyhow::Error),
+}
+
+impl PartialEq for Error {
+    fn eq(&self, other: &Self) -> bool {
+        std::mem::discriminant(self) == std::mem::discriminant(other)
+    }
+}
+
+static APP_USER_AGENT: &str = concat!(env!("CARGO_PKG_NAME"), "-rs/", env!("CARGO_PKG_VERSION"),);
 
 /// Represents the base client interface for IndieWeb activity.
-pub trait Configuration {
+pub trait IConfiguration {
     /// Define the base request.
     fn request(&self, reason: Option<String>) -> reqwest::Client {
         let agent = if APP_USER_AGENT == self.user_agent() {
@@ -33,3 +58,5 @@ pub trait Configuration {
         APP_USER_AGENT
     }
 }
+
+pub type Configuration = dyn IConfiguration + Send + Sync;
