@@ -1,7 +1,7 @@
 #[derive(Default, Clone)]
 pub struct Configuration {}
 
-impl crate::Configuration for Configuration {}
+impl crate::IConfiguration for Configuration {}
 
 impl Copy for Configuration {}
 
